@@ -17,12 +17,18 @@
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
- 
+
+/*--HEADERSTART--*/
+
 // 0.33
-#define KXDOCKERVERSION		"0.0.35"
-#define KXDOCKERNEED		"0.0.12"
-#define KXDOCKERDATE		"20050702"
-#define KXDOCKERHEADERVERSION	"0.0.35"
+#define KXDOCKERVERSION		"1.1.4a"
+#define KXDOCKERNEED		"0.0.16"
+#define KXDOCKERDATE		"20060417"
+#define KXDOCKERHEADERVERSION	"1.0.0"
+
+// 0.37 Gnome support
+// 0.37 KDE support
+#define USE_KWIN
 
  
 // by default 0.26 support threading
@@ -31,6 +37,24 @@
 
 // enable interpolation engine
 #define ENABLE_SPECIALENGINE2
- 
+
+// enable exit by X axis
+#define ENABLE_SPECIALENGINE3
+
+// diable HUGE CACHE
+#define DISABLE_HUGE_CACHE
+
 // this will disable debug messages and a lot of tests!!!
 #define ENABLE_FINAL
+
+// Enable counters and gui statistics, it's a good choice to let's docker know you
+#define ENABLE_STATS
+
+
+// Enable fork to background
+#define DAEMON
+
+#define PILLOWMAXHEIGHT 60
+
+
+/*--HEADERSTOP--*/
