@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004 Stefano <stefano@xiaprojects.com>
+ * Copyright (C) 2006 Stefano <stefano@xiaprojects.com>
  */
 
 #include "kxdocker.h"
@@ -9,9 +9,17 @@
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
 #include <klocale.h>
+#include <kdebug.h>
+
 
 #include "kxdocker_setup_sources.h"
 
+# include <X11/Xlib.h>
+# include <X11/extensions/Xrender.h>
+#include <X11/Xatom.h>
+
+
+
 static const char description[] =
     I18N_NOOP("KXDocker is an innovative <em>docker</em> <br><ul><LI><strong>Skinnable</strong> bar with animated background</LI><LI><strong>Rolling Icons</strong>, our most innovative feature!</LI><LI><strong>AutoResize</strong>, the first docker which will fit always in your screen</LI><LI><strong>Drag'n Drop</strong>support</LI> <LI>Configurable <strong>Xinerama</strong> support</LI><LI><strong>DCOP and Windows tracing</strong>: forget taskbar</LI><LI><strong>Speed</strong>! No computation at runtime</LI><LI>Support for many existing <strong>animation Designs</strong></LI><li>Lots of external <strong>plugins</strong> to manage applications and sensors</li></ul>");
 
@@ -29,7 +37,7 @@ int main(int argc, char **argv)
 			KXDOCKERVERSION,
 			description,
 			KAboutData::License_GPL,
-			"(C) 2002-2005 Stefano",
+			"(C) 2002-2006 Stefano Zingarini",
 			0,
 			"http://www.xiaprojects.com/www/prodotti/kxdocker",
 			"stefano@xiaprojects.com");
@@ -40,10 +48,12 @@ about.addCredit( "Lucio", I18N_NOOP("Contributors"),
 "lucio@xiaprojects.com","http://www.brainsfactory.org" );
 about.addCredit( "Stefano", I18N_NOOP("Contributors"), "stefano@xiaprojects.com","http://www.xiaprojects.com" );
 about.addCredit( "Eric", I18N_NOOP("Contributors"));
+about.addCredit( "Fabio Erculiani - lxnaydesign.net - RR4/RR64 Linux developer", I18N_NOOP("Contributors"));
 about.addCredit( "Magilla", I18N_NOOP("Contributors"));
 about.addCredit( "Michel", I18N_NOOP("Contributors"));
 about.addCredit( "Narcis", I18N_NOOP("Contributors"));
 about.addCredit( "Andreas", I18N_NOOP("Contributors"));
+about.addCredit( "Richard B. Irving, SineWave Technologies, Inc.", I18N_NOOP("Contributors"));
 about.addCredit( "Bruno", I18N_NOOP("Minor developers"));
 about.addCredit( "Filip", I18N_NOOP("Minor developers"));
 about.addCredit( "Lucio", I18N_NOOP("Minor developers"));
@@ -52,13 +62,7 @@ about.addCredit( "Thomas", I18N_NOOP("Minor developers"));
 about.addCredit( "Sebert J.", I18N_NOOP("Minor developers"));
 about.addCredit( "Saurabh", I18N_NOOP("Minor developers"));
 about.addCredit( "Vagninu (Danilo)", I18N_NOOP("Minor developers"));
-
-
-about.setTranslator(I18N_NOOP("_: NAME OF TRANSLATORS\\nYour names")
- ,I18N_NOOP("_: EMAIL OF TRANSLATORS\\nYour emails"));
-/*
-I18N_NOOP("Maintainer")
-*/
+about.setTranslator(I18N_NOOP("_: NAME OF TRANSLATORS\\nYour names"),I18N_NOOP("_: EMAIL OF TRANSLATORS\\nYour emails"));
 
 	KCmdLineArgs::init(argc, argv, &about);
 	KCmdLineArgs::addCmdLineOptions( options );
@@ -66,25 +70,73 @@ I18N_NOOP("Maintainer")
 #ifdef DAEMON
 	if (!KUniqueApplication::start())
 	{
-		qWarning("KXDocker is already running!");
+		kdWarning() <<("KXDocker is already running!\n");
 		return (0);
 	}
-	KUniqueApplication app;
-	KXDocker *mainWin = 0;
+
+
+/********************************************************/
+
+KXDocker::argb_visual=false;
+
+
+
+
+ char *display = 0;
+  Display *dpy = XOpenDisplay( display );
+  if ( !dpy ) {
+    qWarning( "cannot connect to X server ");
+    return( 1 );
+  }
+
+  int screen = DefaultScreen( dpy );
+  Colormap colormap = 0;
+  Visual *visual = 0;
+  int event_base, error_base;
+
+  if (  XRenderQueryExtension( dpy, &event_base, &error_base ) )
+  {
+    int nvi;
+    XVisualInfo templ;
+    templ.screen  = screen;
+    templ.depth   = 32;
+    templ.c_class = TrueColor;
+    XVisualInfo *xvi = XGetVisualInfo( dpy, VisualScreenMask | VisualDepthMask
+		  | VisualClassMask, &templ, &nvi );
+
+    for ( int i = 0; i < nvi; i++ ) {
+      XRenderPictFormat *format = XRenderFindVisualFormat( dpy, xvi[i].visual );
+      if ( format->type == PictTypeDirect && format->direct.alphaMask ) {
+        visual = xvi[i].visual;
+        colormap = XCreateColormap( dpy, RootWindow( dpy, screen ), visual, AllocNone );
+        KXDocker::argb_visual=true;
+        break;
+      }
+    }
+  }
+/******************************************************/
+	//KUniqueApplication app;
+	//KXDocker *mainWin = 0;
+	KXDocker *app;
+if(KXDocker::argb_visual==true){
+	qWarning("KXDocker Will use Composite Extensions!");
+	 app = new KXDocker(dpy, Qt::HANDLE( visual ), Qt::HANDLE( colormap ));
+}
+else{
+	qWarning("Error: KXDocker cannot find Composite Extensions");
+	app = new KXDocker(dpy);
+}
 	// no session.. just start up normally
 	KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 	
 	/// @todo do something with the command line args here
 	
-	mainWin = new KXDocker();
+	//mainWin = new KXDocker();
 	//app.setMainWidget( mainWin );
 	//mainWin->show();
-	
 	args->clear();
 #else
 #endif
-
-
 /*
     if (app.isRestored())
     {
@@ -96,6 +148,6 @@ I18N_NOOP("Maintainer")
 //    }
 
 	// mainWin has WDestructiveClose flag by default, so it will delete itself.
-	return app.exec();
+	return app->exec();
 }
 
