@@ -19,16 +19,20 @@
  ***************************************************************************/
 #ifndef XECONFIGURATION_H
 #define XECONFIGURATION_H
+#include <kxdocker_setup_sources.h>
+
+/*--HEADERSTART--*/
+
 
 #include <qobject.h>
-
 #include <qstring.h>
 #include <qstringlist.h>
 #include <qimage.h>
 #include <qxml.h>
 #include <qdom.h>
 
-#include <kxdocker_setup_sources.h>
+
+
 
 
 const uint MAX_STRING_NAME 	= 50;
@@ -48,14 +52,61 @@ struct XSGObjectIconImages
 	QString imgFileName;
 	QString imgFileArrow;
 	QString imgFileDrop;
+	QString imgFileOverlay;
+	QString imgFileOverlaySpinner;
 	
 };
 
+#ifdef ENABLE_STATS
+struct XSGObjectIconStatistics
+{
+	int onClickExec;
+	int onDropExec;
+	int onBounce;
+	int dockerIndexSum;
+};
+struct XSCfgStatistics
+{
+	int dockerStarts;
+	int dockerDaysRunning;
+	int dockerHoursRunning;
+	int dockerMinutesRunning;
+	int dockerSecondsRunning;
+	int dockerFirstStart;
+	int maxIconsDisplayed;
+	int avgIconsDisplayed;
+	int avgCounter;
+	int changedBackgroundTheme;
+	int startedConfigurator;
+	uint lastStart;
+
+};
+#endif
+
 struct XSGObjectIconActions
 {
 	QString onClickExec;
 	QString onDropExec;
 	QDomNodeList		ActionList;
+	int	iAnimationMask;
+};
+struct XSCfgTextFont
+{
+	int FontRed;
+	int FontGreen;
+	int FontBlue;
+	QString FontFamily;
+	int	FontSize;
+	QString BackgroundPath;
+	int	Bold;
+	int	Italic;
+	int	OtherBinaryValue;
+	int	Weight;
+	int	Other;
+	QString	Alias;
+	int	XPercentageDisplacement;
+	int	YPercentageDisplacement;
+
 };
 
 struct XSCfgTasks
@@ -74,8 +125,12 @@ struct XSCfgTasks
 	QString		dcopNewWindow;
 	int		dcopReady;
 	int		forceRunning;
-	
-	
+	//int		forceNumber;
+	//int		forceString;
+	//int		Number;
+	QString		MiniText;
+	int		MiniTextShow;
+	XSCfgTextFont	MiniTextProperty;
 };
 
 struct XSGObjectIcon
@@ -89,6 +144,10 @@ struct XSGObjectIcon
 	//QImage			Poof;
 	QString			PoofName;
 	class KPopupMenu	*PluginPopupMenu;
+	int			TimeToLive;
+#ifdef ENABLE_STATS
+	XSGObjectIconStatistics	Statistics;
+#endif
 };
 struct XSCfgMatchIcons
 {
@@ -115,12 +174,8 @@ struct XSCfgIcons
 	int Separation;
 	int Horiz;
 	int EnableThumbnail;
-	
-	int FontRed;
-	int FontGreen;
-	int FontBlue;
-	QString FontFamily;
-	int	FontSize;
+	XSCfgTextFont	OverTextFont;
+	XSCfgTextFont	MiniTextFont;
 	
 };
 
@@ -140,7 +195,8 @@ struct XSCfgTheme
 	QString			BackgroundPath;
 	XSGCfgBackground	Background;
 	QString			ArrowsPath;
-	QString			PillowPath;
+//	QString			PillowPath;
+//	QString			MiniPillowPath;
 	QString			PoofPath;
 	QImage			Poof;
 	QStringList		IconsPaths;
@@ -227,12 +283,13 @@ struct XSConfigurations
 	QPtrList<XSGObjectIcon> RollingIcons;
 	XSCfgTheme	Theme;
 	XSCfgPlugins	Plugins;
-	
+#ifdef ENABLE_STATS
+	XSCfgStatistics	Statistics;
+#endif	
 	QStringList	ConfigurationsPaths;
 };
 
 
-
 /**
 @author Stefano
 */
@@ -244,12 +301,13 @@ public:
 
     ~XEConfiguration();
     XSConfigurations * xGetConfiguration();
-
+    XSGObjectIcon * iconAddSeparator();
+    XSGObjectIcon * iconAdd();
 public slots:
     void xReset();
     void xCfgDefault();
     void xSetup();
-    void iconRemove(int);
+    void xEventInRemovingIcon(int,int);
     void xLoadModules();
     void xLoadModule(const QString moduleName);
     void pluginRemove(const QString);
@@ -259,13 +317,32 @@ public slots:
     void xGetConfigurationValue(const QString, QStringList &);
     void xGetConfigurationValue(const QString, int &);
     void xGetConfigurationValue(const QString, QString &);
-    XSGObjectIcon * iconAdd();
+    void xSetConfigurationValue(const QString, QString &);
+    void xEventConfigurationUpdated(const QString);
+    void xSetConfigurationValue(const QString, int &);
+    void xEventInReloadIcon(int);
+    void xFindResource(const QString &, QString &);
+    void xParse(const QString &, int, void *);
+    void xSwapIcons(int,int);
 protected:
     XSConfigurations ActiveConfiguration;
+    QStringList _ValuesList;
+
 signals:
     void xCfgChanged(QObject *);
+    void xEventReloadIcon(int);
+    void xEventRemovingIcon(int,int);
+    void xEventRemovedIcon(int);
 protected:
     void * xGetConfigurationPointer(const QString);
+    void * getConfigurationPointerObject(const QStringList,int,XSGObjectIcon *);
+private:
+    QString xFindIconFile(const QString &);
+    inline int xLoadModuleTest(const QString &);
 };
 
+
+/*--HEADERSTOP--*/
+
+
 #endif
