@@ -17,12 +17,38 @@
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
+
+
+
 #ifndef XEOBJECT_H
 #define XEOBJECT_H
 
 #include <qobject.h>
+
+
+/*--HEADERSTART--*/
+
+
 #include <qptrlist.h> 
 #include <qstringlist.h>
+/*
+#include <time.h>
+
+extern timespec microSeconds;
+//void minisleep(unsigned long);
+
+
+static void minisleep(unsigned long uSeconds)
+{
+	static timespec rem;
+	microSeconds.tv_nsec=1000*uSeconds;
+	microSeconds.tv_sec=0;
+	nanosleep(&microSeconds,&rem);
+}
+*/
+
+
+
 
 /**
 @author Stefano
@@ -48,6 +74,7 @@ public:
     static void xSetEngineMatrix(QObject *);
     void xWarningMsg(const QObject *, const QString &);
     static const QStringList xGetPluginListNames();
+    static int xGetPluginIndex(QObject *);
 protected:
     static QObject * xEngineRoot;
     static QObject * xEngineMatrix;
@@ -63,6 +90,10 @@ public slots:
     static void xPluginDel(QObject *);
     void xGetDocker(QObject *&);
     void xGetConfiguration(QObject  *&);
+    void xParse(const QString &, int, void *);
 };
 
+/*--HEADERSTOP--*/
+
+
 #endif
