@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2004 by Stefano                                         *
- *   stefano@xiaprojects.com                                               *
+ *   Copyright (C) 2005 by Stefano Zingarini   *
+ *   stefano@xiaprojects.com   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -20,17 +20,17 @@
 #ifndef XEPLUGIN_MOUSE_H
 #define XEPLUGIN_MOUSE_H
 
-
 #include <qobject.h>
-#include <qmutex.h>
-
-class QTimer;
-
-
 #include <X11/Xlib.h>
+class QTimer;
+class XSConfigurations;
+class XGDocker;
+class QWidget;
+class QMutex;
+
 
 /**
-@author Stefano
+	@author Stefano Zingarini <stefano@xiaprojects.com>
 */
 class XEPlugin_Mouse : public QObject
 {
@@ -41,33 +41,51 @@ public:
     ~XEPlugin_Mouse();
 protected:
 	QTimer	*MouseTimer;
-	class XSConfigurations *ActiveConfiguration;
-	class XGDocker	*xGDocker;
-//    QPoint oldleft, oldright;
+	XSConfigurations *ActiveConfiguration;
+	XGDocker	*xGDocker;
 	Display *display;
 	Window root, RootIDRet, ChildIDRet;
 	unsigned int StateMask;
-	class QWidget *xGDockerWindow;
+	QWidget *xGDockerWindow;
 	int x,y;
 	int PollingTimeout;
-
+	QMutex *MousePollingMutex;
+	QString onTOPLEFT;
+	QString onBOTTOMLEFT;
+	QString onTOPRIGHT;
+	QString onLEFT;
+	QString onRIGHT;
+	QString onBOTTOMRIGHT;
+	int MonoGo;
+	QTimer *tMonoGo;
+	int iTOPLEFT;
+	int iBOTTOMLEFT;
+	int iTOPRIGHT;
+	int iLEFT;
+	int iRIGHT;
+	int iBOTTOMRIGHT;
 public slots:
-    void xSetup();
-    void xStart();
-    void xStop();
-    void xEventMouseMoved(int,int);
-    void xEventDockerHidden();
-    void stepMouseTracking();
-    void xGetParameter(const QString,QString&);
-    void xGetParameterList(QStringList*);
+	void xSetup();
+	void xStart();
+	void xStop();
+	void xGetParameter(const QString,QString&);
+	void xGetParameterList(QStringList*);
+    void xSetupParameter(const QString sName,const QString sValue);
+    void xGetInfo(QStringList &);
 protected slots:
-	QMutex		MousePollingMutex;
+	void xEventMouseMoved(int,int);
+	void xEventDockerHidden();
+	void stepMouseTracking();
 	void stepMouseTimer();
 	void xEventDockerSendToBackground();
-
+	void releaseKeyForNext();
 signals:
-    void xGetWidget(QWidget *&);
-    void mouseMoveSoftware(int,int);
+	//void xGetWidget(QWidget *&);
+	void mouseMoveSoftware(int,int);
+protected:
+    void updateCfg(const QString, const QString);
+    void sendKeyToX11(int);
+    void checkForExpose(int,int);
 };
 
 #endif
